#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys
import os.path

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))

from gi import require_version
require_version("Gtk", "3.0")

from gi.repository import Gio, Gtk, GLib
from gettext import gettext as _

from gasimport.window import ApplicationWindow

class Application(Gtk.Application):

    def __init__(self):
        Gtk.Application.__init__(self,
                                 application_id="org.gas.importer",
                                 flags=Gio.ApplicationFlags.FLAGS_NONE)

        self.window = None

    def do_startup(self):
        Gtk.Application.do_startup(self)
        self.init_app_menu()

    def do_activate(self):
        # We only allow a single window and raise any existing ones
        if not self.window:
            # Windows are associated with the application
            # when the last one is closed the application shuts down
            self.window = ApplicationWindow(application=self, title="GAS: Importer")

        self.window.present()

    def init_app_menu(self):
        builder = Gtk.Builder()
        builder.add_from_file('../data/ui/app-menu.ui')
        menu = builder.get_object('app-menu')

        action = Gio.SimpleAction.new('settings', None)
        action.connect('activate', self.on_setting)
        self.set_accels_for_action('app.settings', ["<Control>s"])
        self.add_action(action)

        action = Gio.SimpleAction.new("about", None)
        action.connect("activate", self.on_about)
        self.set_accels_for_action('app.about', ["F3"])
        self.add_action(action)

        action = Gio.SimpleAction.new('shortcuts', None)
        action.connect('activate', self.on_shortcut)
        self.set_accels_for_action('app.shortcuts', ["F2"])
        self.add_action(action)

        # F1 - Help

        action = Gio.SimpleAction.new("quit", None)
        action.connect("activate", self.on_quit)
        self.set_accels_for_action('app.quit', ["<Control>q"])
        self.add_action(action)

        #https://github.com/gnumdk/lollypop/blob/036aedd3c36de8b92dfbb02f144d3d0865f547ca/src/application.py#L476
        #if is_gnome() or is_unity():
        #    self.set_app_menu(menu)
        #self.window = Window(self)
        # If not GNOME/Unity add menu to toolbar
        #if not is_gnome() and not is_unity():
        #    self.window.setup_menu(menu)

        self.set_app_menu(menu)

    def do_command_line(self, command_line):
        options = command_line.get_options_dict()

        if options.contains("test"):
            # This is printed on the main instance
            print("Test argument recieved")

        self.activate()
        return 0

    def on_setting(sef, action, param):
        pass

    def on_about(self, action, param):
        builder = Gtk.Builder()
        builder.add_from_file('../data/ui/about.ui')
        dialog = builder.get_object('about_dialog')
        dialog.set_transient_for(self.window)
        dialog.show()

    def on_shortcut(self, action, param):
        builder = Gtk.Builder()
        builder.add_from_file('../data/ui/shortcuts.ui')
        dialog = builder.get_object('shortcuts')
        dialog.set_transient_for(self.window)
        dialog.show()

    def on_quit(self, action, param):
        self.quit()


if __name__ == '__main__':
    app = Application()
    app.run(sys.argv)
